#ifndef NT2_INCLUDE_FUNCTIONS_COTH_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COTH_HPP_INCLUDED

#include <nt2/hyperbolic/include/functions/coth.hpp>

#endif
